package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.FirstLastInspectionMapper;
import com.aucma.base.domain.FirstLastInspection;
import com.aucma.base.service.IFirstLastInspectionService;

@Service
public class FirstLastInspectionServiceImpl implements IFirstLastInspectionService {
    @Autowired
    private FirstLastInspectionMapper firstLastInspectionMapper;

    @Override
    public FirstLastInspection selectFirstLastInspectionByObjId(Long objId) {
        return firstLastInspectionMapper.selectFirstLastInspectionByObjId(objId);
    }

    @Override
    public List<FirstLastInspection> selectFirstLastInspectionList(FirstLastInspection firstLastInspection) {
        return firstLastInspectionMapper.selectFirstLastInspectionList(firstLastInspection);
    }

    @Override
    public int insertFirstLastInspection(FirstLastInspection firstLastInspection) {
        return firstLastInspectionMapper.insertFirstLastInspection(firstLastInspection);
    }

    @Override
    public int updateFirstLastInspection(FirstLastInspection firstLastInspection) {
        return firstLastInspectionMapper.updateFirstLastInspection(firstLastInspection);
    }

    @Override
    public int deleteFirstLastInspectionByObjIds(Long[] objIds) {
        return firstLastInspectionMapper.deleteFirstLastInspectionByObjIds(objIds);
    }

    @Override
    public int deleteFirstLastInspectionByObjId(Long objId) {
        return firstLastInspectionMapper.deleteFirstLastInspectionByObjId(objId);
    }
}
