package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.FirstLastInspection;
import com.aucma.base.service.IFirstLastInspectionService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/base/firstLastInspection" )
public class FirstLastInspectionController extends BaseController {
    @Autowired
    private IFirstLastInspectionService firstLastInspectionService;

    @PreAuthorize("@ss.hasPermi('base:firstLastInspection:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(FirstLastInspection firstLastInspection) {
        startPage();
        List<FirstLastInspection> list = firstLastInspectionService.selectFirstLastInspectionList(firstLastInspection);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('base:firstLastInspection:export')" )
    @Log(title = "首末检验" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, FirstLastInspection firstLastInspection) {
        List<FirstLastInspection> list = firstLastInspectionService.selectFirstLastInspectionList(firstLastInspection);
        ExcelUtil<FirstLastInspection> util = new ExcelUtil<FirstLastInspection>(FirstLastInspection. class);
        util.exportExcel(response, list, "首末检验数据" );
    }

    @PreAuthorize("@ss.hasPermi('base:firstLastInspection:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(firstLastInspectionService.selectFirstLastInspectionByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('base:firstLastInspection:add')" )
    @Log(title = "首末检验" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FirstLastInspection firstLastInspection) {
        firstLastInspection.setCreatedTime(DateUtils.getNowDate());
        return toAjax(firstLastInspectionService.insertFirstLastInspection(firstLastInspection));
    }

    @PreAuthorize("@ss.hasPermi('base:firstLastInspection:edit')" )
    @Log(title = "首末检验" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FirstLastInspection firstLastInspection) {
        firstLastInspection.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(firstLastInspectionService.updateFirstLastInspection(firstLastInspection));
    }

    @PreAuthorize("@ss.hasPermi('base:firstLastInspection:remove')" )
    @Log(title = "首末检验" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(firstLastInspectionService.deleteFirstLastInspectionByObjIds(objIds));
    }

    @PreAuthorize("@ss.hasPermi('base:firstLastInspection:list')" )
    @GetMapping("/getList" )
    public TableDataInfo getList(FirstLastInspection firstLastInspection) {
        List<FirstLastInspection> list = firstLastInspectionService.selectFirstLastInspectionList(firstLastInspection);
        return getDataTable(list);
    }
}
